@@ -2,10 +2,9 @@
 #include <cmath>
 #include <array>
 #include <libdivide.h>
-#include "PrimesSegSieve.h"
-#include "PhiTinyLookup.h"
-
-// [[Rcpp::plugins(cpp11)]]
+#include <PrimesSegSieve.h>
+#include <PhiTinyLookup.h>
+#include <GetFacsUtils.h>
 
 // "AllPrimesCpp" implements a simple segmented version of the
 // Sieve of Eratosthenes (original implementation authored by 
@@ -19,8 +18,6 @@
 // Kim Walisch's official github repo for "pi_legendre" is:
 //                      https://github.com/kimwalisch/primecount
 
-const double Significand53 = 9007199254740991.0;
-
 // This is the largest multiple of 2*3*5*7 = 210
 // that is less than 2^15 = 32768 = 32KB. This
 // is the typical size of most CPU's L1 cache
